Index: views/controls/menu/menu_item_view.h |
=================================================================== |
--- views/controls/menu/menu_item_view.h (revision 91956) |
+++ views/controls/menu/menu_item_view.h (working copy) |
@@ -406,8 +406,8 @@ |
int GetTopMargin(); |
int GetBottomMargin(); |
- // Returns the preferred width (and padding) of any children. |
- int GetChildPreferredWidth(); |
+ // Returns the preferred size (and padding) of any children. |
+ gfx::Size GetChildPreferredSize(); |
// Calculates the preferred size. |
gfx::Size CalculatePreferredSize(); |